from util_array import pillam, charactors, vowels

def sinhala_to_singlish(input_text):
    output_array = []

    for i, char in enumerate(input_text[:-1]):
        e_char = charactors.get(char)
        p_char = pillam.get(char)

        is_vowel = char in vowels

        if e_char:
            # Preserve spaces
            output_array.append(char if char == ' ' else e_char)

            # Check for pillam and append 'a'
            next_char = input_text[i + 1]
            output_array.append(pillam.get(next_char) or 'a' if e_char and char != ' ' else '')

        elif not e_char and not p_char:
            # Character not found in mapping, keep the original character
            output_array.append(char)

        if is_vowel:
            if output_array:
                output_array.pop()

    # Add the last character to the output
    output_array.append(charactors.get(input_text[-1], input_text[-1]))

    return "".join(output_array)



from setuptools import setup, find_packages

with open("README.md", "r") as fh: 
    description = fh.read() 

setup(
    name='siconv',
    version='0.1.1.3',
    author='sahan ruwantha',
    author_email='sahanr.silva@proton.me',
    description='''The siconv Python package simplifies the conversion between Sinhala and Singlish languages. Whether you're dealing with Sinhala text that needs transformation into Singlish or vice versa, siconv offers a user-friendly solution.''',
    long_description=description,
    long_description_content_type="text/markdown", 
    url="https://github.com/sahanruwantha/siconv", 
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
